Package: geneClassifiers
Type: Package
Title: Application of gene classifiers
Version: 1.35.0
Authors@R: c(
    person("R","Kuiper",email="r.kuiper.emc@gmail.com",role=c("cre","aut"),comment = c(ORCID = "0000-0002-3703-1762"))
    )
Description: This packages aims for easy accessible application of
        classifiers which have been published in literature using an
        ExpressionSet as input.
URL: https://doi.org/doi:10.18129/B9.bioc.geneClassifiers
BugReports: https://github.com/rkuiper/geneClassifiers/issues
License: GPL-2
biocViews: GeneExpression, BiomedicalInformatics, Classification,
        Survival, Microarray
LazyData: true
Suggests: testthat
Depends: R (>= 3.6.0)
Imports: utils, methods, stats, Biobase, BiocGenerics
Collate: aaa.R allGenericFunctions.R Class_TransformationProcess.R
        Class_FixedExpressionData.R Class_ClassifierParameters.R
        Class_ClassifierResults.R zzz.R geneClassifiers.R
RoxygenNote: 6.1.1
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/geneClassifiers
git_branch: devel
git_last_commit: c28693f
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: no
Packaged: 2025-10-30 21:14:08 UTC; biocbuild
Author: R Kuiper [cre, aut] (ORCID: <https://orcid.org/0000-0002-3703-1762>)
Maintainer: R Kuiper <r.kuiper.emc@gmail.com>
