#' @details
#' Combining gene expression profiling data with survival data has led to the 
#' development of robust outcome predictors (gene classifiers).This package 
#' provides a method for running gene classifiers generating patient specific 
#' predictive outcomes. This package is intended to support and enable 
#' research. To yield stable results, this package requires a dataset of
#' at least 20 patients.
#'
#' For detail on how to use this package see the vignette: 
#' \code{vignette('geneClassifiers')}
#'
#' @references
#' Kuiper R, Broyl A, de Knegt YA, Van Vliet MH, Van Beers EH, van der Holt B, el Jarari L, Mulligan G, Gregory W, Morgan G, Goldschmidt H. A gene expression signature for high-risk multiple myeloma. Leukemia. 2012 Nov;26(11):2406.
#' @keywords internal
"_PACKAGE"
# > [1] '_PACKAGE'

