% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Class_FixedExpressionData.R
\docType{data}
\name{exampleMAS5}
\alias{exampleMAS5}
\title{Example MAS5.0 ExpressionSet}
\format{An object of class \code{ExpressionSet} with 374 rows and 25 columns.}
\usage{
exampleMAS5
}
\description{
An \code{\link{ExpressionSet}}. The data contains a sample of gene expression 
data from patients included in the HOVON65/GMMG-HD4 trial on multiple myeloma. 
The data was MAS5.0 normalized to a target value of 500.
}
\keyword{datasets}
